# -*- coding: utf-8 -*-
#
# Copyright 2012 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Main module to open the GTK UI."""

import argparse

# pylint: disable=E0611
from gi.repository import Gtk
# pylint: enable=E0611

from ubuntu_sso.gtk.gui import UbuntuSSOClientGUI


def parse_args():
    """Parse sys.argv options."""
    parser = argparse.ArgumentParser(description='Open the GTK SSO UI.')
    parser.add_argument('--app_name', required=True,
        help='the name of the application to retrieve credentials for')
    parser.add_argument('--ping_url', default='',
        help='a link to be used as the ping url (to notify about new tokens)')
    parser.add_argument('--tc_url', default='',
        help='a link to be used as Terms & Conditions url')
    parser.add_argument('--help_text', default='',
        help='extra text that will be shown below the headers')
    parser.add_argument('--window_id', type=int, default=0,
        help='the window id to be set transient for the SSO GTK dialogs')
    parser.add_argument('--login_only', action='store_true', default=False,
        help='whether the SSO GTK UI should only offer login or not')

    args = parser.parse_args()
    return args


def main(**kwargs):
    """Start the GTK mainloop and open the main window."""
    UbuntuSSOClientGUI(close_callback=Gtk.main_quit, **kwargs)
    Gtk.main()
