# -*- coding: utf-8 -*-
#
# Copyright 2012 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Page to allow the user to sign in."""

import gettext

from PyQt4 import QtGui

from ubuntu_sso.qt.gui import SSOWizardPage
from ubuntu_sso.logger import setup_logging
from ubuntu_sso.utils.ui import (
    CONGRATULATIONS,
    EXISTING_ACCOUNT_CHOICE_BUTTON,
    SET_UP_ACCOUNT_CHOICE_BUTTON,
)


_ = gettext.gettext
logger = setup_logging('ubuntu_sso.sing_in_page')


class SignInPage(SSOWizardPage):
    """Wizard Page that lets the user Sign into Ubuntu One."""

    def __init__(self, ui, image_pixmap, *args, **kwargs):
        super(SignInPage, self).__init__(ui, *args, **kwargs)
        self.ui.image_label.setPixmap(image_pixmap)
        self._set_up_translated_strings()
        self._connect_buttons()

    def _set_up_translated_strings(self):
        """Set the correct strings for the UI."""
        logger.debug('SingInPage._set_up_translated_strings')
        congratulations = CONGRATULATIONS.format(app_name=self.app_name)
        self.ui.message_label.setText(congratulations)
        self.ui.existing_account_button.setText(
                                        EXISTING_ACCOUNT_CHOICE_BUTTON)
        self.ui.setup_account_button.setText(
                                        SET_UP_ACCOUNT_CHOICE_BUTTON)

    def _connect_buttons(self):
        """Connect the buttons to the actions to perform."""
        logger.debug('SingInPage._connect_buttons')
        self.ui.existing_account_button.clicked.connect(
                                                    self._set_next_existing)
        self.ui.setup_account_button.clicked.connect(self._set_next_new)

    def _set_next_existing(self):
        """Set the next id and fire signal."""
        logger.debug('SignInPage._set_next_existing')
        self.next = self.wizard().current_user_page_id
        self.wizard().next()

    def _set_next_new(self):
        """Set the next id and fire signal."""
        logger.debug('SignInPage._set_next_new')
        self.next = self.wizard().setup_account_page_id
        self.wizard().next()

    # Invalid names of Qt-inherited methods
    # pylint: disable=C0103

    def initializePage(self):
        """Setup UI details."""
        self.ui.cancel_button.setText(_("Close window and setup later"))
        self.ui.cancel_button.clicked.connect(self.wizard().reject)
        # Layout without custom button 1,
        # without finish button
        # without cancel
        self.wizard().setButtonLayout([
            QtGui.QWizard.Stretch,
            QtGui.QWizard.NextButton])

    def showEvent(self, event):
        """Set existing_account_button as default when the page is shown."""
        super(SignInPage, self).showEvent(event)
        self.ui.existing_account_button.setDefault(True)
        self.ui.existing_account_button.style().unpolish(
            self.ui.existing_account_button)
        self.ui.existing_account_button.style().polish(
            self.ui.existing_account_button)

    def nextId(self):
        """Provide the next id."""
        return self.next
