# -*- coding: utf-8 -*-
#
# Copyright 2011 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
"""A common webclient that can use a QtNetwork or libsoup backend."""

import sys

# pylint: disable=W0611
from ubuntu_sso.utils.webclient.common import (
    UnauthorizedError,
    WebClientError,
)


def is_qt4reactor_installed():
    """Check if the qt4reactor is installed."""
    reactor = sys.modules.get("twisted.internet.reactor")
    return reactor and getattr(reactor, "qApp", None)


def webclient_module():
    """Choose the module of the web client."""
    if is_qt4reactor_installed():
        from ubuntu_sso.utils.webclient import qtnetwork as web_module
    else:
        from ubuntu_sso.utils.webclient import libsoup as web_module
        #from ubuntu_sso.utils.webclient import txweb as web_module
    return web_module


def webclient_factory(*args, **kwargs):
    """Choose the type of the web client dynamically."""
    web_module = webclient_module()
    return web_module.WebClient(*args, **kwargs)
