# -*- coding: utf-8 -*-
#
# Copyright 2011 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
"""Retrieve the proxy configuration from Gnome."""

import subprocess

GSETTINGS_CMDLINE = "gsettings list-recursively org.gnome.system.proxy"


def get_proxy_settings():
    """Parse the proxy settings as returned by the gsettings executable."""
    output = subprocess.check_output(GSETTINGS_CMDLINE.split())
    gsettings = {}
    base_len = len("org.gnome.system.proxy.")
    # pylint: disable=E1103
    for line in output.split("\n"):
        try:
            path, key, value = line.split(" ", 2)
        except ValueError:
            continue
        if value.startswith("'"):
            parsed_value = value[1:-1]
        elif value.startswith('['):
            parsed_value = value
        elif value in ('true', 'false'):
            parsed_value = (value == 'true')
        else:
            parsed_value = int(value)
        relative_key = (path + "." + key)[base_len:]
        gsettings[relative_key] = parsed_value

    mode = gsettings["mode"]
    if mode == "none":
        settings = {}
    elif mode == "manual":
        settings = {
            "host": gsettings["http.host"],
            "port": gsettings["http.port"],
        }
        if gsettings["http.use-authentication"]:
            settings.update({
                "username": gsettings["http.authentication-user"],
                "password": gsettings["http.authentication-password"],
            })
    else:
        # If mode is automatic the PAC javascript should be interpreted
        # on each request. That is out of scope so it's ignored for now
        settings = {}

    return settings
